@@ -21,6 +21,8 @@ package org.apache.maven.plugin.plugin;
 
 import org.apache.maven.artifact.Artifact;
 import org.apache.maven.artifact.repository.ArtifactRepository;
+import org.apache.maven.artifact.resolver.filter.ArtifactFilter;
+import org.apache.maven.artifact.resolver.filter.IncludesArtifactFilter;
 import org.apache.maven.plugin.AbstractMojo;
 import org.apache.maven.plugin.MojoExecutionException;
 import org.apache.maven.plugin.descriptor.InvalidPluginDescriptorException;
@@ -35,10 +37,12 @@ import org.apache.maven.tools.plugin.generator.Generator;
 import org.apache.maven.tools.plugin.generator.GeneratorException;
 import org.apache.maven.tools.plugin.generator.GeneratorUtils;
 import org.apache.maven.tools.plugin.scanner.MojoScanner;
+import org.codehaus.plexus.component.repository.ComponentDependency;
 import org.codehaus.plexus.util.ReaderFactory;
 
 import java.io.File;
 import java.util.Arrays;
+import java.util.LinkedHashSet;
 import java.util.List;
 import java.util.Set;
 
@@ -46,7 +50,7 @@ import java.util.Set;
  * Abstract class for this Plugin.
  *
  * @author <a href="mailto:jason@maven.org">Jason van Zyl</a>
- * @version $Id: AbstractGeneratorMojo.java 1588273 2014-04-17 15:06:59Z ifedorenko $
+ * @version $Id: AbstractGeneratorMojo.java 1756035 2016-08-11 19:43:10Z rfscholte $
  */
 public abstract class AbstractGeneratorMojo
     extends AbstractMojo
@@ -54,7 +58,7 @@ public abstract class AbstractGeneratorMojo
     /**
      * The project currently being built.
      */
-    @Component
+    @Parameter( defaultValue = "${project}", readonly = true )
     protected MavenProject project;
 
     /**
@@ -128,6 +132,16 @@ public abstract class AbstractGeneratorMojo
      */
     @Parameter( defaultValue = "${project.artifacts}", required = true, readonly = true )
     protected Set<Artifact> dependencies;
+    
+    /**
+     * Specify the dependencies as {@code groupId:artifactId} containing (abstract) Mojos.
+     * If not specified in the configuration, this is {@code null} and all dependencies are scanned.
+     * If specified with no children, no dependencies are scanned.
+     * 
+     * @since 3.5
+     */
+    @Parameter
+    private List<String> mojoDependencies;
 
     /**
      * List of Remote Repositories used by the resolver
@@ -222,21 +236,47 @@ public abstract class AbstractGeneratorMojo
         if ( encoding == null || encoding.length() < 1 )
         {
             getLog().warn( "Using platform encoding (" + ReaderFactory.FILE_ENCODING
-                               + " actually) to read mojo metadata, i.e. build is platform dependent!" );
+                               + " actually) to read mojo source files, i.e. build is platform dependent!" );
         }
         else
         {
-            getLog().info( "Using '" + encoding + "' encoding to read mojo metadata." );
+            getLog().info( "Using '" + encoding + "' encoding to read mojo source files." );
         }
 
+        Set<Artifact> requestDependencies;
+        if ( mojoDependencies == null )
+        {
+            requestDependencies = dependencies;
+        }
+        else if ( mojoDependencies == null )
+        {
+            requestDependencies = null;
+        }
+        else
+        {
+            requestDependencies = new LinkedHashSet<Artifact>();
+            
+            ArtifactFilter filter = new IncludesArtifactFilter( mojoDependencies );
+
+            for ( Artifact artifact : dependencies )
+            {
+                if ( filter.include( artifact ) )
+                {
+                    requestDependencies.add( artifact );
+                }
+            }
+        }
+        
+        
         try
         {
-            pluginDescriptor.setDependencies( GeneratorUtils.toComponentDependencies( project.getRuntimeDependencies() ) );
+            List<ComponentDependency> deps = GeneratorUtils.toComponentDependencies( project.getRuntimeDependencies() );
+            pluginDescriptor.setDependencies( deps );
 
             PluginToolsRequest request = new DefaultPluginToolsRequest( project, pluginDescriptor );
             request.setEncoding( encoding );
             request.setSkipErrorNoDescriptorsFound( skipErrorNoDescriptorsFound );
-            request.setDependencies( dependencies );
+            request.setDependencies( requestDependencies );
             request.setLocal( this.local );
             request.setRemoteRepos( this.remoteRepos );
 
