@@ -24,10 +24,10 @@ import org.apache.maven.artifact.repository.ArtifactRepository;
 import org.apache.maven.doxia.sink.Sink;
 import org.apache.maven.doxia.siterenderer.Renderer;
 import org.apache.maven.model.Plugin;
-import org.apache.maven.model.ReportPlugin;
 import org.apache.maven.plugin.descriptor.InvalidPluginDescriptorException;
 import org.apache.maven.plugin.descriptor.MojoDescriptor;
 import org.apache.maven.plugin.descriptor.PluginDescriptor;
+import org.apache.maven.plugin.descriptor.PluginDescriptorBuilder;
 import org.apache.maven.plugins.annotations.Component;
 import org.apache.maven.plugins.annotations.Execute;
 import org.apache.maven.plugins.annotations.LifecyclePhase;
@@ -45,10 +45,14 @@ import org.apache.maven.tools.plugin.generator.GeneratorUtils;
 import org.apache.maven.tools.plugin.generator.PluginXdocGenerator;
 import org.apache.maven.tools.plugin.scanner.MojoScanner;
 import org.apache.maven.tools.plugin.util.PluginUtils;
+import org.codehaus.plexus.component.repository.ComponentDependency;
+import org.codehaus.plexus.configuration.PlexusConfigurationException;
 import org.codehaus.plexus.util.StringUtils;
 import org.codehaus.plexus.util.xml.Xpp3Dom;
 
 import java.io.File;
+import java.io.FileNotFoundException;
+import java.io.FileReader;
 import java.util.ArrayList;
 import java.util.Iterator;
 import java.util.List;
@@ -58,11 +62,12 @@ import java.util.ResourceBundle;
 import java.util.Set;
 
 /**
- * Generates the Plugin's documentation report.
+ * Generates the Plugin's documentation report: <code>plugin-info.html</code> plugin overview page,
+ * and one <code><i>goal</i>-mojo.html</code> per goal.
  *
  * @author <a href="snicoll@apache.org">Stephane Nicoll</a>
  * @author <a href="mailto:vincent.siveton@gmail.com">Vincent Siveton</a>
- * @version $Id: PluginReport.java 1588642 2014-04-19 11:31:57Z rfscholte $
+ * @version $Id: PluginReport.java 1756054 2016-08-11 21:47:06Z rfscholte $
  * @since 2.0
  */
 @Mojo( name = "report", threadSafe = true )
@@ -71,7 +76,7 @@ public class PluginReport
     extends AbstractMavenReport
 {
     /**
-     * Report output directory for mojo pages.
+     * Report output directory for mojos' documentation.
      */
     @Parameter( defaultValue = "${project.build.directory}/generated-site/xdoc" )
     private File outputDirectory;
@@ -85,7 +90,7 @@ public class PluginReport
     /**
      * The Maven Project.
      */
-    @Component
+    @Parameter( defaultValue = "${project}", readonly = true )
     private MavenProject project;
 
     /**
@@ -218,7 +223,6 @@ public class PluginReport
     /**
      * {@inheritDoc}
      */
-    @SuppressWarnings( "unchecked" )
     protected void executeReport( Locale locale )
         throws MavenReportException
     {
@@ -232,6 +236,35 @@ public class PluginReport
             return;
         }
 
+        PluginDescriptor pluginDescriptor = extractPluginDescriptor();
+
+        // Generate the mojos' documentation
+        generateMojosDocumentation( pluginDescriptor, locale );
+
+        // Write the overview
+        PluginOverviewRenderer r =
+            new PluginOverviewRenderer( project, requirements, getSink(), pluginDescriptor, locale );
+        r.render();
+    }
+
+    private PluginDescriptor extractPluginDescriptor()
+        throws MavenReportException
+    {
+        PluginDescriptorBuilder builder = new PluginDescriptorBuilder();
+        try
+        {
+            return builder.build( new FileReader( new File( project.getBuild().getOutputDirectory(),
+                                                            "META-INF/maven/plugin.xml" ) ) );
+        }
+        catch ( FileNotFoundException e )
+        {
+            getLog().debug( "Failed to read META-INF/maven/plugin.xml, fall back to mojoScanner" );
+        }
+        catch ( PlexusConfigurationException e )
+        {
+            getLog().debug( "Failed to read META-INF/maven/plugin.xml, fall back to mojoScanner" );
+        }
+
         // Copy from AbstractGeneratorMojo#execute()
         String defaultGoalPrefix = PluginDescriptor.getGoalPrefixFromArtifactId( project.getArtifactId() );
         if ( goalPrefix == null )
@@ -257,7 +290,9 @@ public class PluginReport
 
         try
         {
-            pluginDescriptor.setDependencies( GeneratorUtils.toComponentDependencies( project.getRuntimeDependencies() ) );
+            @SuppressWarnings( "unchecked" )
+            List<ComponentDependency> deps = GeneratorUtils.toComponentDependencies( project.getRuntimeDependencies() );
+            pluginDescriptor.setDependencies( deps );
 
             PluginToolsRequest request = new DefaultPluginToolsRequest( project, pluginDescriptor );
             request.setEncoding( encoding );
@@ -266,7 +301,6 @@ public class PluginReport
             request.setLocal( this.local );
             request.setRemoteRepos( this.remoteRepos );
 
-
             try
             {
                 mojoScanner.populatePluginDescriptor( request );
@@ -275,23 +309,14 @@ public class PluginReport
             {
                 // this is OK, it happens to lifecycle plugins. Allow generation to proceed.
                 getLog().debug( "Plugin without mojos.", e );
-
             }
-
-            // Generate the plugin's documentation
-            generatePluginDocumentation( pluginDescriptor, locale );
-
-            // Write the overview
-            PluginOverviewRenderer r =
-                new PluginOverviewRenderer( project, requirements, getSink(), pluginDescriptor, locale );
-            r.render();
         }
-
         catch ( ExtractionException e )
         {
             throw new MavenReportException( "Error extracting plugin descriptor: \'" + e.getLocalizedMessage() + "\'",
                                             e );
         }
+        return pluginDescriptor;
     }
 
     /**
@@ -319,11 +344,13 @@ public class PluginReport
     }
 
     /**
+     * Generate the mojos documentation, as xdoc files.
+     *
      * @param pluginDescriptor not null
      * @param locale           not null
      * @throws MavenReportException if any
      */
-    private void generatePluginDocumentation( PluginDescriptor pluginDescriptor, Locale locale )
+    private void generateMojosDocumentation( PluginDescriptor pluginDescriptor, Locale locale )
         throws MavenReportException
     {
         try
@@ -653,10 +680,13 @@ public class PluginReport
         }
 
         /**
-         * Try to lookup on the <code>org.apache.maven.plugins:maven-compiler-plugin</code> plugin to
-         * find the value of the <code>target</code> option.
-         * If not specified, uses the value defined by the user.
-         * If not specified, uses the value of the system property <code>java.specification.version</code>.
+         * <ol>
+         * <li>use configured jdk requirement</li>
+         * <li>use <code>target</code> configuration of <code>org.apache.maven.plugins:maven-compiler-plugin</code></li>
+         * <li>use <code>target</code> configuration of <code>org.apache.maven.plugins:maven-compiler-plugin</code> in
+         * <code>pluginManagement</code></li>
+         * <li>use <code>maven.compiler.target</code> property</li>
+         * </ol>
          *
          * @param project      not null
          * @param requirements not null
@@ -665,84 +695,67 @@ public class PluginReport
         private static String discoverJdkRequirement( MavenProject project, Requirements requirements )
         {
             String jdk = requirements.getJdk();
-            if ( jdk == null )
-            {
-                jdk = discoverJdkRequirementFromPlugins( project.getBuild().getPluginsAsMap() );
-            }
-            if ( jdk == null && project.getPluginManagement() != null )
-            {
-                    jdk = discoverJdkRequirementFromPlugins( project.getPluginManagement().getPluginsAsMap() );
-            }
-            if ( jdk == null )
-            {
-                jdk = "Unknown";
-            }
 
-            return jdk;
-        }
-
-        /**
-         * @param pluginsAsMap could be null
-         * @return the value of the <code>target</code> in the configuration of <code>maven-compiler-plugin</code>.
-         */
-        @SuppressWarnings( "rawtypes" )
-        private static String discoverJdkRequirementFromPlugins( Map pluginsAsMap )
-        {
-            if ( pluginsAsMap == null )
-            {
-                return null;
-            }
-
-            String jdk = null;
-            String backupJdk = null;
-            for ( Iterator it = pluginsAsMap.keySet().iterator(); it.hasNext(); )
-            {
-                String key = it.next().toString();
-
-                if ( !key.equals( "org.apache.maven.plugins:maven-compiler-plugin" ) )
-                {
-                    continue;
-                }
-
-                Object value = pluginsAsMap.get( key );
-                Xpp3Dom pluginConf = null;
-
-                backupJdk = "Default version for maven-compiler-plugin";
-                if ( value instanceof Plugin )
-                {
-                    Plugin plugin = (Plugin) value;
-                    backupJdk = "Default target for maven-compiler-plugin version " + plugin.getVersion();
-                    pluginConf = (Xpp3Dom) plugin.getConfiguration();
-                }
-
-                if ( value instanceof ReportPlugin )
-                {
-                    ReportPlugin reportPlugin = (ReportPlugin) value;
-                    backupJdk = "Default target for maven-compiler-plugin version " + reportPlugin.getVersion();
-                    pluginConf = (Xpp3Dom) reportPlugin.getConfiguration();
-                }
-
-                if ( pluginConf == null )
-                {
-                    continue;
-                }
-
-                if ( pluginConf.getChild( "target" ) == null )
-                {
-                    continue;
-                }
-
-                jdk = pluginConf.getChild( "target" ).getValue();
-            }
-
-            if ( jdk == null )
-            {
-                return backupJdk;
-            }
-            else
+            if ( jdk != null )
             {
                 return jdk;
             }
+
+            @SuppressWarnings( "unchecked" )
+            Plugin compiler = getCompilerPlugin( project.getBuild().getPluginsAsMap() );
+            if ( compiler == null )
+            {
+                compiler = getCompilerPlugin( project.getPluginManagement().getPluginsAsMap() );
+            }
+
+            jdk = getPluginParameter( compiler, "target" );
+            if ( jdk != null )
+            {
+                return jdk;
+            }
+
+            // default value
+            jdk = project.getProperties().getProperty( "maven.compiler.target" );
+            if ( jdk != null )
+            {
+                return jdk;
+            }
+
+            // return "1.5" by default?
+
+            String version = ( compiler == null ) ? null : compiler.getVersion();
+
+            if ( version != null )
+            {
+                return "Default target for maven-compiler-plugin version " + version;
+            }
+
+            return "Unknown";
+        }
+
+        private static Plugin getCompilerPlugin( Map<String, Object> pluginsAsMap )
+        {
+            return (Plugin) pluginsAsMap.get( "org.apache.maven.plugins:maven-compiler-plugin" );
+        }
+
+        private static String getPluginParameter( Plugin plugin, String parameter )
+        {
+            if ( plugin != null )
+            {
+                Xpp3Dom pluginConf = (Xpp3Dom) plugin.getConfiguration();
+
+                if ( pluginConf != null )
+                {
+                    Xpp3Dom target = pluginConf.getChild( parameter );
+
+                    if ( target != null )
+                    {
+                        return target.getValue();
+                    }
+                }
+            }
+
+            return null;
         }
     }
 }
