@@ -82,21 +82,21 @@ public class DefaultMojoScanner
 
         int numMojoDescriptors = 0;
 
-        for ( String language : activeExtractorsInternal )
+        for ( String extractorId : activeExtractorsInternal )
         {
-            MojoDescriptorExtractor extractor = mojoDescriptorExtractors.get( language );
+            MojoDescriptorExtractor extractor = mojoDescriptorExtractors.get( extractorId );
 
             if ( extractor == null )
             {
-                throw new ExtractionException( "No mojo extractor for language: " + language );
+                throw new ExtractionException( "No mojo extractor with '" + extractorId + "' id." );
             }
 
-            logger.info( "Applying mojo extractor for language: " + language );
+            logger.debug( "Applying " + extractorId + " mojo extractor" );
 
             List<MojoDescriptor> extractorDescriptors = extractor.execute( request );
 
-            logger.info( "Mojo extractor for language: " + language + " found " + extractorDescriptors.size()
-                             + " mojo descriptors." );
+            logger.info( extractorId + " mojo extractor found " + extractorDescriptors.size()
+                             + " mojo descriptor" + ( extractorDescriptors.size() > 1 ? "s" : "" ) + "." );
             numMojoDescriptors += extractorDescriptors.size();
 
             for ( MojoDescriptor descriptor : extractorDescriptors )
