@@ -57,7 +57,7 @@ import org.w3c.tidy.Tidy;
  * Convenience methods to play with Maven plugins.
  *
  * @author jdcasey
- * @version $Id: GeneratorUtils.java 1342928 2012-05-26 17:12:27Z hboutemy $
+ * @version $Id: GeneratorUtils.java 1642372 2014-11-28 22:41:25Z hboutemy $
  */
 public final class GeneratorUtils
 {
@@ -359,7 +359,7 @@ public final class GeneratorUtils
          */
         class Counter
         {
-            public int value;
+            int value;
         }
 
         /**
