@@ -45,8 +45,7 @@ import java.util.ResourceBundle;
 /**
  * Generate xdoc documentation for each mojo.
  *
- * @version $Id: PluginXdocGenerator.java 1341236 2012-05-21 22:37:15Z hboutemy $
- * @todo add example usage tag that can be shown in the doco
+ * @version $Id: PluginXdocGenerator.java 1754050 2016-07-25 21:19:22Z gboue $
  */
 public class PluginXdocGenerator
     implements Generator
@@ -544,6 +543,10 @@ public class PluginXdocGenerator
             addedUl = addUl( w, addedUl, parameter.getDefaultValue() );
             writeDetail( getString( "pluginxdoc.mojodescriptor.parameter.default" ),
                          escapeXml( parameter.getDefaultValue() ), w );
+            
+            addedUl = addUl( w, addedUl, parameter.getAlias() );
+            writeDetail( getString( "pluginxdoc.mojodescriptor.parameter.alias" ), escapeXml( parameter.getAlias() ),
+                         w );
 
             if ( addedUl )
             {
@@ -720,6 +723,13 @@ public class PluginXdocGenerator
             if ( property != null )
             {
                 w.writeMarkup( format( "pluginxdoc.mojodescriptor.parameter.property.description", property ) );
+                w.writeMarkup( "<br/>" );
+            }
+            
+            if ( StringUtils.isNotEmpty( parameter.getAlias() ) )
+            {
+                w.writeMarkup( format( "pluginxdoc.mojodescriptor.parameter.alias.description",
+                                       escapeXml( parameter.getAlias() ) ) );
             }
 
             w.endElement(); //td
