@@ -21,10 +21,11 @@ package org.apache.maven.tools.plugin.javadoc;
 
 import java.util.Map;
 
-import org.apache.maven.tools.plugin.extractor.java.JavaMojoAnnotation;
+import org.apache.maven.tools.plugin.extractor.javadoc.JavadocMojoAnnotation;
 
 import com.sun.tools.doclets.Taglet;
 
+// CHECKSTYLE_OFF: LineLength
 /**
  * The <tt>@parameter</tt> tag is used to define a Mojo parameter and has annotation parameter.
  * <br/>
@@ -50,21 +51,22 @@ import com.sun.tools.doclets.Taglet;
  * @see <a href="package-summary.html#package_description">package-summary.html</a>
  *
  * @author <a href="mailto:vincent.siveton@gmail.com">Vincent Siveton</a>
- * @version $Id: MojoParameterFieldTaglet.java 1592217 2014-05-03 15:20:29Z hboutemy $
+ * @version $Id: MojoParameterFieldTaglet.java 1648914 2015-01-01 17:43:20Z hboutemy $
  */
+//CHECKSTYLE_ON: LineLength
 public class MojoParameterFieldTaglet
     extends AbstractMojoFieldTaglet
 {
     /** The Javadoc annotation */
-    private static final String NAME = JavaMojoAnnotation.PARAMETER;
+    private static final String NAME = JavadocMojoAnnotation.PARAMETER;
 
     private static final String[] PARAMETERS_NAME = {
-        JavaMojoAnnotation.PARAMETER_NAME,
-        JavaMojoAnnotation.PARAMETER_ALIAS,
-        JavaMojoAnnotation.PARAMETER_DEFAULT_VALUE,
-        JavaMojoAnnotation.PARAMETER_EXPRESSION,
-        JavaMojoAnnotation.PARAMETER_IMPLEMENTATION,
-        JavaMojoAnnotation.PARAMETER_PROPERTY };
+        JavadocMojoAnnotation.PARAMETER_NAME,
+        JavadocMojoAnnotation.PARAMETER_ALIAS,
+        JavadocMojoAnnotation.PARAMETER_DEFAULT_VALUE,
+        JavadocMojoAnnotation.PARAMETER_EXPRESSION,
+        JavadocMojoAnnotation.PARAMETER_IMPLEMENTATION,
+        JavadocMojoAnnotation.PARAMETER_PROPERTY };
 
     /** The Javadoc text which will be added to the generated page. */
     protected static final String HEADER = "Is defined by";
